@@ -1,8 +1,6 @@
-from dodo_commands.dependencies.get import funcy
+from dodo_commands.framework import ramda as R
 from dodo_commands.framework.global_config import load_global_config_parser
 
-merge = funcy.merge
-
 
 class Commands:
     def __init__(self):
@@ -14,7 +12,7 @@ class Commands:
 
     @property
     def aliases(self):
-        return merge(self.global_aliases, self.aliases_from_config)
+        return R.merge(self.global_aliases, self.aliases_from_config)
 
     @staticmethod
     def get(ctr):
@@ -23,6 +21,6 @@ class Commands:
 
 def init_commands(self):
     global_config = load_global_config_parser()
-    if global_config.has_section('alias'):
-        self.global_aliases = dict(global_config.items('alias'))
+    if global_config.has_section("alias"):
+        self.global_aliases = dict(global_config.items("alias"))
     return self
